@import url('https://fonts.googleapis.com/css2?family=Atkinson+Hyperlegible:ital,wght@0,400;0,700;1,400;1,700&family=Spline+Sans+Mono:ital,wght@0,300..700;1,300..700&display=swap');

h1 {
	font-size: 2.0rem;
}

h2 {
	font-size: 1.75rem;
}

h3 {
	font-size: 1.5rem;
}

.toctree-l2 {
	font-size: 0.85rem;
}

article {
	font-size: 0.9rem;
}

div.cell div.cell_input {
	padding-left: 0em;
	padding-right: 0em;
	border: 1px rgba(127, 127, 127, 0.1) solid;
	background-color: rgba(127, 127, 127, 0.1);
	border-left-color: hsl(126, 25%, 45%);
	border-left-width: medium;
}

.cell_output .output.text_plain, .cell_output .output.traceback, .cell_output .output.stream {
	border: 1px solid rgba(127, 127, 127, 0.0);
    background: rgba(127, 127, 127, 0.0);
	margin-top: 0em;
	margin-bottom: 0em;
	margin-left: 0.5em;
	box-shadow: none;
}

.cell_output .output.stderr {
	border: 1px solid rgba(127, 127, 127, 0.0);
    background: rgba(127, 127, 127, 0.0);
	margin-top: 0em;
	margin-bottom: 0em;
	margin-left: 0.25em;
	box-shadow: none;
    border-left-color: #cc7766;
    border-left-width: medium;
}

.cell_output {
	padding-left: 1em;
	padding-right: 0em;
	margin-top: 0em;
}